parseCompactDate method
Converts the given compact date formatted string into a DateTime.
The format of the string must be a valid compact date format for the
given locale. If the text doesn't represent a valid date, null will be
returned.
See also:
- formatCompactDate, which will convert a DateTime into a string in the compact format.
Implementation
@override
DateTime? parseCompactDate(
String? inputString, MaterialLocalizations localizations) {
return localizations.parseCompactDate(inputString);
}