general_datetime library

This file is startup of general_datetime library you can use the package consider the example

Classes

GeneralDateTimeInterface<T>
HijriDateTime
Represents a date and time in the Hijri (Islamic) calendar system using the Umm al-Qura calculation method.
PersianDateTime
Represents a date and time in the Persian (Persian/Iranian) calendar system.